# PySentry - pip-audit Benchmark Report

**Generated:** 2026-01-28 02:01:19
**Duration:** 1m 39.15s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.365s) - 24.29x faster than slowest
- **Memory Efficient:** pysentry-pypi (17.23 MB) - 5.39x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.275s) - 28.25x faster than slowest
- **Memory Efficient:** pysentry-pypi (8.02 MB) - 11.69x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (1.057s) - 16.57x faster than slowest
- **Memory Efficient:** pysentry-osv (38.27 MB) - 2.70x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.765s) - 20.01x faster than slowest
- **Memory Efficient:** pysentry-osv (10.99 MB) - 8.63x less memory than highest

## Test Environment

- **Platform:** Linux-6.11.0-1018-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.14
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.73 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.365s | 1.00x |
| 🥈 pysentry-osv | 0.716s | 1.96x |
|  pysentry-all-sources | 1.040s | 2.85x |
|  pysentry-pypa | 1.293s | 3.54x |
|  pip-audit-default | 8.858s | 24.29x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 17.23 MB | 1.00x |
| 🥈 pysentry-osv | 18.96 MB | 1.10x |
|  pip-audit-default | 45.70 MB | 2.65x |
|  pysentry-pypa | 60.56 MB | 3.51x |
|  pysentry-all-sources | 92.95 MB | 5.39x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.275s | 1.00x |
| 🥈 pysentry-osv | 0.441s | 1.61x |
|  pysentry-pypa | 0.873s | 3.17x |
|  pysentry-all-sources | 1.048s | 3.81x |
|  pip-audit-default | 7.768s | 28.25x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 8.02 MB | 1.00x |
| 🥈 pysentry-osv | 10.35 MB | 1.29x |
|  pip-audit-default | 44.99 MB | 5.61x |
|  pysentry-pypa | 48.39 MB | 6.03x |
|  pysentry-all-sources | 93.72 MB | 11.69x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 1.057s | 1.00x |
| 🥈 pysentry-osv | 1.181s | 1.12x |
|  pysentry-all-sources | 1.458s | 1.38x |
|  pysentry-pypa | 1.622s | 1.53x |
|  pip-audit-default | 17.517s | 16.57x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 38.27 MB | 1.00x |
| 🥈 pysentry-pypi | 42.65 MB | 1.11x |
|  pip-audit-default | 48.46 MB | 1.27x |
|  pysentry-pypa | 83.79 MB | 2.19x |
|  pysentry-all-sources | 103.46 MB | 2.70x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.765s | 1.00x |
| 🥈 pysentry-osv | 1.154s | 1.51x |
|  pysentry-pypa | 1.392s | 1.82x |
|  pysentry-all-sources | 1.524s | 1.99x |
|  pip-audit-default | 15.315s | 20.01x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 10.99 MB | 1.00x |
| 🥈 pysentry-pypi | 11.45 MB | 1.04x |
|  pysentry-pypa | 45.54 MB | 4.14x |
|  pip-audit-default | 47.70 MB | 4.34x |
|  pysentry-all-sources | 94.80 MB | 8.63x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 1.013s, Min: 0.275s, Max: 1.622s

- **Memory Usage:** Avg: 48.82 MB, Min: 8.02 MB, Max: 103.46 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 12.364s, Min: 7.768s, Max: 17.517s

- **Memory Usage:** Avg: 46.71 MB, Min: 44.99 MB, Max: 48.46 MB

- **Success Rate:** 100.0% (4/4)